@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: DemoSpace.cpp,v 1.13 2009/02/09 09:04:45 bowkenken Exp $
+* $Id: DemoSpace.cpp,v 1.14 2009/06/03 19:25:22 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -552,7 +552,7 @@ void DemoSpace::drawStaffRoll()
 
 	if( y < (sh / 2) )
 		if( get_scene() != SCENE_N_ENDING_END )
-			change_scene( SCENE_N_ENDING_END );
+			change_scene_gui( SCENE_N_ENDING_END );
 }
 
 ////////////////////////////////////////////////////////////////
