@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GameSound.h,v 1.4 2009/05/20 04:11:09 bowkenken Exp $
+* $Id: GameSound.h,v 1.6 2009/05/31 07:23:57 bowkenken Exp $
 ***************************************************************/
 
 #ifndef GAME_SOUND_H
@@ -68,18 +68,71 @@ struct LsSound {
 ////////////////////////////////////////////////////////////////
 
 class GameSound {
-public:
 private:
-	LsSound lsDoorOpen;
+	int	nPhaserChannel;
+
+	LsSound lsTrapSafe;
+	LsSound lsTrapDisarm;
+	LsSound lsTrapCaught;
+
+	LsSound lsSpellSor;
+	LsSound lsSpellEnc;
+	LsSound lsSpellNin;
+	LsSound lsSpellBar;
+	LsSound lsSpellMag;
+	LsSound lsSpellSum;
+	LsSound lsSpellSha;
+	LsSound lsSpellPri;
+
+	LsSound lsBlastMember;
+	LsSound lsBlastMonster;
+	LsSound lsBlastDestruction;
+
+	LsSound lsMenuCancel;
+	LsSound lsMenuSelect;
+
+	LsSound lsFightDieMember;
+	LsSound lsFightDieMonsterBossLast;
+	LsSound lsFightDieMonsterBoss;
+	LsSound lsFightDieMonster;
+	LsSound lsFightDefenseMissMember;
+	LsSound lsFightDefenseMissMonsterBossLast;
+	LsSound lsFightDefenseMissMonster;
+	LsSound lsFightDefenseHitMember;
+	LsSound lsFightDefenseHitMonster;
+	LsSound lsFightDefenseCriticalMember;
+	LsSound lsFightDefenseCriticalMonster;
+	LsSound lsFightFindMember;
+	LsSound lsFightFindMonsterBoss;
+	LsSound lsFightFindMonster;
+	LsSound lsFightAttackLastBossAttack;
+	LsSound lsFightAttackLastBossWeaken;
+	LsSound lsFightAttackLastBossSlap;
+	LsSound lsFightAttackThrowMember;
+	LsSound lsFightAttackThrowMonster;
+
+	LsSound lsRequestFinish;
+
+	LsSound lsShopSale;
+	LsSound lsShopBuyDrink;
+	LsSound lsShopBuy;
+
+	LsSound lsEventGate;
+	LsSound lsEventDrive;
+	LsSound lsEventEarthquake;
+
+	LsSound lsLevelDown;
+	LsSound lsLevelUp;
+
 	LsSound lsDoorClose;
+	LsSound lsDoorOpen;
 
-	LsSound lsShopPay;
-	LsSound lsShopDrink;
+	LsSound lsStairsDown;
+	LsSound lsStairsUp;
 
-	LsSound lsHitMbr;
-	LsSound lsHitMnstr;
-	LsSound lsCrtclMbr;
-	LsSound lsCrtclMnstr;
+	LsSound lsItemUse;
+	LsSound lsItemOpen;
+	LsSound lsItemSmoke;
 
 public:
 	GameSound();
@@ -88,6 +141,7 @@ public:
 	void close();
 
 	void play( sound_kind_t kind, long nRepeat );
+	void stop();
 
 private:
 	void initLsSound( LsSound *ls, WSCstring dir );
