@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: fight.c,v 1.162 2009/07/12 09:02:11 bowkenken Exp $
+* $Id: fight.c,v 1.163 2009/07/13 07:01:42 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -1245,8 +1245,8 @@ bool_t	fight_x_1(
 		str_nz_cpy( d_name, MSG_NULL, CHR_NAME_MAX_BYTE );
 		d_hp = NULL;
 		d_fx = NULL;
-		d_x = 0;
-		d_y = 0;
+		d_x = o_p->trgt.true_x;
+		d_y = o_p->trgt.true_y;
 	} else {
 		str_nz_cpy( d_name, d_p->name, CHR_NAME_MAX_BYTE );
 		d_hp = &(d_p->abl.hp);
@@ -1502,8 +1502,18 @@ bool_t	fight_x_1(
 
 	/* 񤹤 */
 
-	if( attack->flg_throw && (eq != NULL) && (o_k == CHR_KIND_MBR) ){
-		if( (eq[EQUIP_KIND_ARW].kind == ITEM_KIND_WPN)
+	do {
+		if( !attack->flg_throw )
+			break;
+		if( eq == NULL )
+			break;
+		if( o_k != CHR_KIND_MBR )
+			break;
+
+		if( flg_d_null ){
+			/* 񤻤 */
+			dec_throw( (mbr_t *)o_p, TRUE, d_x, d_y );
+		} else if( (eq[EQUIP_KIND_ARW].kind == ITEM_KIND_WPN)
 				&& chk_flg( eq[EQUIP_KIND_ARW].dat.wpn.flg,
 				FLG_WPN_TAB_NOT_SPEND ) ){
 			/* 񤻤 */
@@ -1511,7 +1521,9 @@ bool_t	fight_x_1(
 		} else {
 			dec_throw( (mbr_t *)o_p, FALSE, d_x, d_y );
 		}
-	}
+
+		break;
+	} while( 0 );
 
 	/* Ƥ */
 
