@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: last-boss.c,v 1.73 2009/06/06 12:29:12 bowkenken Exp $
+* $Id: last-boss.c,v 1.75 2009/06/26 16:58:16 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -57,6 +57,8 @@ static const long	XX_ENTER_WAIT = 3;
 static const long	XX_CORE_OFFSET_X = 0;
 static const long	XX_CORE_OFFSET_Y = 2;
 
+check_memory_def( check_memory_last_boss_c_EXEL_JUMP_MAX_Y )
+
 /***************************************************************
 * XX
 ***************************************************************/
@@ -68,6 +70,8 @@ static pos_t	g_core;
 static last_boss_ptn_t	last_boss_ptn_bg;
 static last_boss_ptn_t	last_boss_ptn_fg;
 
+check_memory_def( check_memory_last_boss_c_xx_pos )
+
 /*  */
 
 static last_boss_joint_t	*joint_skull;
@@ -94,6 +98,8 @@ static last_boss_joint_t	*joint_hand_to_fore_arm_right;
 static last_boss_joint_t	*joint_hand_to_fore_arm_slap_left;
 static last_boss_joint_t	*joint_hand_to_fore_arm_slap_right;
 
+check_memory_def( check_memory_last_boss_c_joint_skull )
+
 static pos_t	pos_skull;
 static pos_t	pos_jaw;
 static pos_t	pos_jaw_open;
@@ -109,10 +115,14 @@ static pos_t	pos_hand_right;
 static pos_t	pos_hand_slap_left;
 static pos_t	pos_hand_slap_right;
 
+check_memory_def( check_memory_last_boss_c_pos_skull )
+
 static bool_t	flg_open_xx_jaw;
 static bool_t	flg_slap_xx_arm_left;
 static bool_t	flg_slap_xx_arm_right;
 
+check_memory_def( check_memory_last_boss_c_flg_open_xx_jaw )
+
 /***************************************************************
 * XX βǮ
 ***************************************************************/
@@ -120,8 +130,10 @@ static bool_t	flg_slap_xx_arm_right;
 /* δֳ */
 static const long	XX_HEAT_DY = 3;
 static const long	XX_HEAT_ANIME_N = 5;
+check_memory_def( check_memory_last_boss_c_XX_HEAT_DY )
 
 static const long	XX_HEAT_WAIT_FRAME_N = 3;
+check_memory_def( check_memory_last_boss_c_XX_HEAT_WAIT_FRAME_N )
 
 static blast_t	xx_blast_heat[] = {
 	{
@@ -165,6 +177,7 @@ static blast_t	xx_blast_heat[] = {
 		},
 	},
 };
+check_memory_def( check_memory_last_boss_c_xx_blast_heat )
 
 /***************************************************************
 * XX ο乶
@@ -172,11 +185,13 @@ static blast_t	xx_blast_heat[] = {
 
 static const rate_t	XX_COLD_LASER_MAX_LEN = 10;
 static const rate_t	XX_COLD_LASER_ADD_LEN = 1;
+check_memory_def( check_memory_last_boss_c_XX_COLD_LASER_MAX_LEN )
 
 static const long	XX_COLD_BIT_WAIT_FRAME_N = 3;
 static const long	XX_COLD_NEXT_WAIT_FRAME_N = 30;
 static const long	XX_COLD_LASER_WAIT_FRAME_N = 3;
 static const long	XX_COLD_END_WAIT_FRAME_N = 60;
+check_memory_def( check_memory_last_boss_c_XX_COLD_BIT_WAIT_FRAME_N )
 
 static const char	*xx_laser[MBR_MAX_N] = {
 	"|",
@@ -186,6 +201,7 @@ static const char	*xx_laser[MBR_MAX_N] = {
 	"-",
 	"-",
 };
+check_memory_def( check_memory_last_boss_c_xx_laser )
 
 static pos_t	xx_laser_dxy[MBR_MAX_N] = {
 	{ +-0,  +1 },
@@ -195,6 +211,7 @@ static pos_t	xx_laser_dxy[MBR_MAX_N] = {
 	{  +1, +-0 },
 	{  -1, +-0 },
 };
+check_memory_def( check_memory_last_boss_c_xx_laser_dxy )
 
 static blast_t	xx_bit[MBR_MAX_N] = {
 	{
@@ -258,18 +275,22 @@ static blast_t	xx_bit[MBR_MAX_N] = {
 		},
 	},
 };
+check_memory_def( check_memory_last_boss_c_xx_bit )
 
 /***************************************************************
 * XX 
 ***************************************************************/
 
 static const rate_t	XX_MIND_ADD_RATE = 10;
+check_memory_def( check_memory_last_boss_c_XX_MIND_ADD_RATE )
 
 static const long	XX_MIND_ANIME_N = 5;
 static const long	XX_MIND_WAIT_FRAME_N = 3;
+check_memory_def( check_memory_last_boss_c_XX_MIND_ANIME_N )
 
 static const char	*xx_refract_head = "**";
 static const char	*xx_refract_image = "oo";
+check_memory_def( check_memory_last_boss_c_xx_refract_head )
 
 static void xx_mind_refract( xx_mind_t *xx_mind );
 static void xx_mind_move( xx_mind_t *xx_mind );
@@ -282,8 +303,10 @@ static void xx_mind_draw( xx_mind_t *xx_mind );
 #define	XX_ACID_HOMING_V	(1.0 * XX_ACID_HOMING_FIX_POINT)
 
 static const double	XX_ACID_MAX_Q = 18.0;
+check_memory_def( check_memory_last_boss_c_XX_ACID_MAX_Q )
 
 static const long	XX_ACID_WAIT_FRAME_N = 3;
+check_memory_def( check_memory_last_boss_c_XX_ACID_WAIT_FRAME_N )
 
 static pos_t	xx_homing_bgn_v[MBR_MAX_N] = {
 	{ -0.1, -XX_ACID_HOMING_V },
@@ -293,10 +316,12 @@ static pos_t	xx_homing_bgn_v[MBR_MAX_N] = {
 	{ -XX_ACID_HOMING_V, +-0.0 },
 	{ +XX_ACID_HOMING_V, +-0.0 },
 };
+check_memory_def( check_memory_last_boss_c_xx_homing_bgn_v )
 
 static const char	*xx_homing_head = "OO";
 static const char	*xx_homing_image = "oo";
 static const char	*xx_homing_tail = "++";
+check_memory_def( check_memory_last_boss_c_xx_homing_head )
 
 static bool_t xx_acid_chk_end( xx_acid_t *xx_acid );
 static void xx_acid_move( xx_acid_t *xx_acid );
@@ -308,8 +333,10 @@ static void xx_acid_draw( xx_acid_t *xx_acid );
 
 static const long	XX_ROTATION_ANIME_N = 2;
 static const long	XX_ROTATION_WAIT_FRAME_N = 6;
+check_memory_def( check_memory_last_boss_c_XX_ROTATION_ANIME_N )
 
 static const char	*xx_rotation_str = "o";
+check_memory_def( check_memory_last_boss_c_xx_rotation_str )
 
 /***************************************************************
 * XX αƹ
@@ -317,8 +344,10 @@ static const char	*xx_rotation_str = "o";
 
 static const long	XX_WHIRL_ANIME_N = 2;
 static const long	XX_WHIRL_WAIT_FRAME_N = 3;
+check_memory_def( check_memory_last_boss_c_XX_WHIRL_ANIME_N )
 
 static const char	*xx_whirl_str = "x";
+check_memory_def( check_memory_last_boss_c_xx_whirl_str )
 
 /***************************************************************
 * XX ƹ
@@ -326,14 +355,17 @@ static const char	*xx_whirl_str = "x";
 
 static const long	XX_FAN_ANIME_N = 2;
 static const long	XX_FAN_WAIT_FRAME_N = 3;
+check_memory_def( check_memory_last_boss_c_XX_FAN_ANIME_N )
 
 static const char	*xx_fan_str = "*";
+check_memory_def( check_memory_last_boss_c_xx_fan_str )
 
 /***************************************************************
 * XX ʿǤ
 ***************************************************************/
 
 static const long	XX_SLAP_WAIT_FRAME_N = 60;
+check_memory_def( check_memory_last_boss_c_XX_SLAP_WAIT_FRAME_N )
 
 static attack_t	xx_attack_slap[] = {
 	{ ATTACK_KIND_XX_SLAP, 1, FALSE, TRUE,
@@ -349,6 +381,7 @@ static attack_t	xx_attack_slap[] = {
 		SPELL_KIND_NULL,
 		EXTENT_KIND_NULL, N_MSG_NULL, },
 };
+check_memory_def( check_memory_last_boss_c_xx_attack_slap )
 
 /***************************************************************
 * 
@@ -1336,7 +1369,7 @@ void	draw_xx_enter( void )
 	bgn_time = time( NULL );
 	flg_end = FALSE;
 
-	call_game_sound_play( SOUND_KIND_EVENT_EARTHQUAKE, 10 );
+	call_game_sound_play( SOUND_KIND_EVENT_EARTHQUAKE, 20 );
 
 	for( i = 0; i < LOOP_MAX_1000; i++ ){
 		/*  */
@@ -3871,3 +3904,67 @@ void	xx_act_slap_draw( mnstr_t *p )
 
 	wait_frame( XX_SLAP_WAIT_FRAME_N );
 }
+
+/***************************************************************
+* ꡼å
+***************************************************************/
+
+void	check_memory_last_boss_c( void )
+{
+	check_memory( check_memory_last_boss_c_EXEL_JUMP_MAX_Y,
+			"last-boss.c: EXEL_JUMP_MAX_Y" );
+	check_memory( check_memory_last_boss_c_xx_pos,
+			"last-boss.c: xx_pos" );
+	check_memory( check_memory_last_boss_c_joint_skull,
+			"last-boss.c: joint_skull" );
+	check_memory( check_memory_last_boss_c_pos_skull,
+			"last-boss.c: pos_skull" );
+	check_memory( check_memory_last_boss_c_flg_open_xx_jaw,
+			"last-boss.c: flg_open_xx_jaw" );
+	check_memory( check_memory_last_boss_c_XX_HEAT_DY,
+			"last-boss.c: XX_HEAT_DY" );
+	check_memory( check_memory_last_boss_c_XX_HEAT_WAIT_FRAME_N,
+			"last-boss.c: XX_HEAT_WAIT_FRAME_N" );
+	check_memory( check_memory_last_boss_c_xx_blast_heat,
+			"last-boss.c: xx_blast_heat" );
+	check_memory( check_memory_last_boss_c_XX_COLD_LASER_MAX_LEN,
+			"last-boss.c: XX_COLD_LASER_MAX_LEN" );
+	check_memory( check_memory_last_boss_c_XX_COLD_BIT_WAIT_FRAME_N,
+			"last-boss.c: XX_COLD_BIT_WAIT_FRAME_N" );
+	check_memory( check_memory_last_boss_c_xx_laser,
+			"last-boss.c: xx_laser" );
+	check_memory( check_memory_last_boss_c_xx_laser_dxy,
+			"last-boss.c: xx_laser_dxy" );
+	check_memory( check_memory_last_boss_c_xx_bit,
+			"last-boss.c: xx_bit" );
+	check_memory( check_memory_last_boss_c_XX_MIND_ADD_RATE,
+			"last-boss.c: XX_MIND_ADD_RATE" );
+	check_memory( check_memory_last_boss_c_XX_MIND_ANIME_N,
+			"last-boss.c: XX_MIND_ANIME_N" );
+	check_memory( check_memory_last_boss_c_xx_refract_head,
+			"last-boss.c: xx_refract_head" );
+	check_memory( check_memory_last_boss_c_XX_ACID_MAX_Q,
+			"last-boss.c: XX_ACID_MAX_Q" );
+	check_memory( check_memory_last_boss_c_XX_ACID_WAIT_FRAME_N,
+			"last-boss.c: XX_ACID_WAIT_FRAME_N" );
+	check_memory( check_memory_last_boss_c_xx_homing_bgn_v,
+			"last-boss.c: xx_homing_bgn_v" );
+	check_memory( check_memory_last_boss_c_xx_homing_head,
+			"last-boss.c: xx_homing_head" );
+	check_memory( check_memory_last_boss_c_XX_ROTATION_ANIME_N,
+			"last-boss.c: XX_ROTATION_ANIME_N" );
+	check_memory( check_memory_last_boss_c_xx_rotation_str,
+			"last-boss.c: xx_rotation_str" );
+	check_memory( check_memory_last_boss_c_XX_WHIRL_ANIME_N,
+			"last-boss.c: XX_WHIRL_ANIME_N" );
+	check_memory( check_memory_last_boss_c_xx_whirl_str,
+			"last-boss.c: xx_whirl_str" );
+	check_memory( check_memory_last_boss_c_XX_FAN_ANIME_N,
+			"last-boss.c: XX_FAN_ANIME_N" );
+	check_memory( check_memory_last_boss_c_xx_fan_str,
+			"last-boss.c: xx_fan_str" );
+	check_memory( check_memory_last_boss_c_XX_SLAP_WAIT_FRAME_N,
+			"last-boss.c: XX_SLAP_WAIT_FRAME_N" );
+	check_memory( check_memory_last_boss_c_xx_attack_slap,
+			"last-boss.c: xx_attack_slap" );
+}
