@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: spell-tab.h,v 1.18 2009/01/04 00:24:52 bowkenken Exp $
+* $Id: spell-tab.h,v 1.19 2009/07/12 17:27:30 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	SPELL_TAB_H
@@ -1492,6 +1492,16 @@ menu_t	ls_menu_spell[] = {
 		FLG_NULL,
 	},
 
+	{
+		"/spell/PRI/cure_hallucination",
+		"<Branch>",
+		'\0',
+		"",
+		N_MSG_SPELL_CURE_HALLUCINATION, "",
+		cb_menu_spell, (void *)SPELL_KIND_CURE_HALLUCINATION,
+		FLG_NULL,
+	},
+
 	{
 		"/spell/PRI/cure_charm",
 		"<Branch>",
@@ -1842,16 +1852,6 @@ menu_t	ls_menu_spell[] = {
 		FLG_NULL,
 	},
 
-	{
-		"/spell/SHA/summon_salamander",
-		"<Branch>",
-		'\0',
-		"",
-		N_MSG_SPELL_SUMMON_SALAMANDER, "",
-		cb_menu_spell, (void *)SPELL_KIND_SUMMON_SALAMANDER,
-		FLG_NULL,
-	},
-
 	{
 		"/spell/SHA/summon_water_elemental",
 		"<Branch>",
@@ -1862,16 +1862,6 @@ menu_t	ls_menu_spell[] = {
 		FLG_NULL,
 	},
 
-	{
-		"/spell/SHA/summon_undine",
-		"<Branch>",
-		'\0',
-		"",
-		N_MSG_SPELL_SUMMON_UNDINE, "",
-		cb_menu_spell, (void *)SPELL_KIND_SUMMON_UNDINE,
-		FLG_NULL,
-	},
-
 	{
 		"/spell/SHA/summon_air_elemental",
 		"<Branch>",
@@ -1882,16 +1872,6 @@ menu_t	ls_menu_spell[] = {
 		FLG_NULL,
 	},
 
-	{
-		"/spell/SHA/summon_sylph",
-		"<Branch>",
-		'\0',
-		"",
-		N_MSG_SPELL_SUMMON_SYLPH, "",
-		cb_menu_spell, (void *)SPELL_KIND_SUMMON_SYLPH,
-		FLG_NULL,
-	},
-
 	{
 		"/spell/SHA/summon_earth_elemental",
 		"<Branch>",
@@ -1902,16 +1882,6 @@ menu_t	ls_menu_spell[] = {
 		FLG_NULL,
 	},
 
-	{
-		"/spell/SHA/summon_gnome",
-		"<Branch>",
-		'\0',
-		"",
-		N_MSG_SPELL_SUMMON_GNOME, "",
-		cb_menu_spell, (void *)SPELL_KIND_SUMMON_GNOME,
-		FLG_NULL,
-	},
-
 	{
 		"/spell/SHA/summon_will_o_wisp",
 		"<Branch>",
@@ -1932,6 +1902,46 @@ menu_t	ls_menu_spell[] = {
 		FLG_NULL,
 	},
 
+	{
+		"/spell/SHA/summon_salamander",
+		"<Branch>",
+		'\0',
+		"",
+		N_MSG_SPELL_SUMMON_SALAMANDER, "",
+		cb_menu_spell, (void *)SPELL_KIND_SUMMON_SALAMANDER,
+		FLG_NULL,
+	},
+
+	{
+		"/spell/SHA/summon_undine",
+		"<Branch>",
+		'\0',
+		"",
+		N_MSG_SPELL_SUMMON_UNDINE, "",
+		cb_menu_spell, (void *)SPELL_KIND_SUMMON_UNDINE,
+		FLG_NULL,
+	},
+
+	{
+		"/spell/SHA/summon_sylph",
+		"<Branch>",
+		'\0',
+		"",
+		N_MSG_SPELL_SUMMON_SYLPH, "",
+		cb_menu_spell, (void *)SPELL_KIND_SUMMON_SYLPH,
+		FLG_NULL,
+	},
+
+	{
+		"/spell/SHA/summon_gnome",
+		"<Branch>",
+		'\0',
+		"",
+		N_MSG_SPELL_SUMMON_GNOME, "",
+		cb_menu_spell, (void *)SPELL_KIND_SUMMON_GNOME,
+		FLG_NULL,
+	},
+
 	{
 		"/spell/SHA/no_learn summon elemental",
 		"<Item>",
@@ -2501,7 +2511,7 @@ menu_t	ls_menu_spell[] = {
 		NULL, NULL,
 		FLG_NULL,
 	},
-/*  */
+/**/
 	{
 		"",
 		"",
