@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: spell.c,v 1.198 2009/06/27 23:34:50 bowkenken Exp $
+* $Id: spell.c,v 1.202 2009/07/23 12:52:01 bowkenken Exp $
 ***************************************************************/
 
 #define	SPELL_C
@@ -49,16 +49,16 @@
 
 #define	SKELETON_WARRIOR_STD_N	2
 
-#define	DISMISSAL_TURN_BONE	64
-#define	DISMISSAL_TURN_SKELETON	96
-#define	DISMISSAL_TURN_UNICORN	64
-#define	DISMISSAL_TURN_EFREET	64
-#define	DISMISSAL_TURN_DJINNI	64
-#define	DISMISSAL_TURN_PHOENIX	32
-#define	DISMISSAL_TURN_ELEMENTAL	32
+#define	DISMISSAL_TURN_BONE	128
+#define	DISMISSAL_TURN_SKELETON	128
+#define	DISMISSAL_TURN_UNICORN	128
+#define	DISMISSAL_TURN_EFREET	128
+#define	DISMISSAL_TURN_DJINNI	128
+#define	DISMISSAL_TURN_PHOENIX	128
+#define	DISMISSAL_TURN_ELEMENTAL	64
 
 #define	SPELL_NIN_RATE	((rate_t)80)
-#define	SPELL_SHA_DIV_RESI_RATE	4
+#define	SPELL_SHA_RESI_DIV_RATE	((rate_t)400)
 
 #define	BAR_LIMIT_LEV	10
 
@@ -807,17 +807,20 @@ void	chr_cast_spell( chr_t *chr, spell_tab_t *tab, const char *fmt )
 	if( (tab->resi_down > 0) && (resi < 1) )
 		resi = 1;
 
-	{
+	if( resi > 0 ){
 		long	resi_div;
 
 		resi_div = get_lev( chr, ABL_KIND_SHA )
 				+ get_lev( chr, ABL_KIND_CHA );
-		resi_div /= SPELL_SHA_DIV_RESI_RATE;
+		resi_div *= SPELL_SHA_RESI_DIV_RATE;
+		resi_div /= _100_PERCENT;
 		if( resi_div < 1 )
 			resi_div = 1;
 
 		resi *= _100_PERCENT;
 		resi /= resi_div;
+		if( resi < 1 )
+			resi = 1;
 	}
 
 	if( chr->abl.hp.n < hp ){
@@ -843,21 +846,16 @@ void	chr_cast_spell( chr_t *chr, spell_tab_t *tab, const char *fmt )
 		if( kind >= RESI_KIND_MAX_N )
 			return;
 
-		d = chr->resi[kind].n - ((resi / _100_PERCENT) + 1);
+		d = chr->resi[kind].n - resi;
 		if( d <= 0 ){
 			clr_chr_trgt_act( chr, TRUE );
 			print_msg_mbr( chr, FLG_NULL,
 					MSG_ERR_RESI_SHORT,
-					chr->name, -d + 1 );
+					chr->name, (long)-d + 1 );
 			return;
 		}
 
-		add_resi( chr, kind, -(resi / _100_PERCENT), TRUE );
-		if( (resi % _100_PERCENT) != 0 ){
-			if( rate_randm( resi % _100_PERCENT ) ){
-				add_resi( chr, kind, -1, TRUE );
-			}
-		}
+		add_resi( chr, kind, -resi, TRUE );
 	}
 
 	add_mp( chr, -mp, TRUE );
